@@ -429,10 +429,16 @@ class RedisRoot:
         
         return sorted(instances, key=(lambda instance: instance[field_name]), reverse=reverse)
     
+    def get_wait_creating(self):
+        self.redis_instance.get(f'__creating__:{self.prefix}')
+    
+    def set_wait_creating(self, is_creating):
+        self.redis_instance.set(f'__creating__:{self.prefix}', is_creating)
+    
     def wait_creation(self):
-        while self.wait_creating:
+        while self.get_wait_creating():
             pass
-        self.wait_creating = True
+        self.set_wait_creating(True)
     
     def get_and_reserve_new_id(self, model):
         
@@ -454,8 +460,9 @@ class RedisRoot:
             new_id = really_new()
         else:
             new_id = self.creating[model][-1] + 1
-        self.wait_creating = False
+        self.set_wait_creating(False)
         return new_id
+
     
     def remove_creating(self, model, instance_id):
         self.wait_creation()
@@ -464,7 +471,7 @@ class RedisRoot:
             for some_instance_id in self.creating[model].copy()
             if some_instance_id != instance_id
         ]
-        self.wait_creating = False
+        self.set_wait_creating(False)
     
     ### GET ###
     
@@ -965,7 +972,7 @@ class RedisModel:
     def _get_and_reserve_new_id(self):
         redis_root = self.get('redis_root')
         self.id.value = redis_root.get_and_reserve_new_id(self.__class__)
-    
+
     def _set_fields(self, instance_key, fields_dict):
         model_ttl = self.get_model_ttl()
         redis_root = self.get('redis_root')
@@ -1027,3 +1034,4 @@ class RedisModel:
             return meta
         else:
             raise Exception(f'{name} has no field {field_name}')
+
